<?php

App::uses('AppHelper', 'View/Helper');

class CustomFieldsHelper extends AppHelper
{
    /**
     * get custom field data from the name for the template
     *
     * @param   string      the custom field to get
     * @param   mixed       Default value if the actual value cannot be found
     * @param   string      name of the array containing the custom field data (defaults to data)
     * @return  mixed
     */
    public function get($name, $default = '', $dataVar = 'data')
    {
        if (! isset($this->_View->viewVars[$dataVar]['CustomFieldData'])) {
            return $default;
        }

        $fields = Hash::combine($this->_View->viewVars[$dataVar]['CustomFieldData'], '{n}.Field.name', '{n}');

        $value = Hash::get($fields, $name . '.FieldData.value');

        if ($value === null) {
            return $default;
        }

        return $value;
    }


    /**
     * inject the tab into the form
     *
     */
    public function injectAdminForm()
    {
        echo $this->element(
            'form_tab',
            array(
                'title' => 'Custom Fields',
                'tabContent' => $this->element('EvCustomFields.selection/fieldSelectionTab'),
                'divOptions' => array(
                    'class' => 'custom-field-selection'
                )
            )
        );
    }


    /**
     * clean the attribute array for use on addField
     *
     * @param   array   Array of data from the CustomField array
     * @return  array   Cleaned array for addField - removes names / validation rules
     */
    public function cleanAttrArray($attr)
    {
        unset(
            $attr['name'],
            $attr['validation'],
            $attr['model'],
            $attr['model_id'],
            $attr['sequence'],
            $attr['is_active'],
            $attr['created'],
            $attr['modified']
        );

        if (! empty($attr['options'])) {
            $attr['options'] = $this->formatOptions($attr['options']);
        } else {
            unset($attr['options']);
        }

        return $attr;
    }


    /**
     * format any options the array may have
     *
     * @param   array   Options array
     * @return  array   formatted Options array
     */
    public function formatOptions($options)
    {
        if (empty($options) || ! is_array($options)) {
            return array();
        }

        return Hash::combine(
            $options,
            '{n}.value',
            '{n}.label'
        );
    }
}
